pub struct Tag<'a> {
pub word: &'a str,
pub tag: &'a str,
pub start: usize,
pub end: usize,
pub byte_start: usize,
pub byte_end: usize,
}Expand description
A tagged word
Fields
word: &'a strWord
tag: &'a strWord tag
start: usizeUnicode start position of the word in the original input
end: usizeUnicode end position of the word in the original input
byte_start: usizeByte start position of the word in the original input
byte_end: usizeByte end position of the word in the original input